Create SummarizedExperiment object from FLAMES output folder
Source: R/methods-SingleCellPipeline.R
create_se_from_dir.RdCreate SummarizedExperiment object from FLAMES output folder
Arguments
- outdir
The folder containing
FLAMESoutput files- annotation
(Optional) the annotation file that was used to produce the output files
- quantification
(Optional) the quantification method used to generate the output files (either "FLAMES" or "Oarfish".). If not specified, the function will attempt to determine the quantification method.
Examples
ppl <- example_pipeline("BulkPipeline")
#> ℹ Writing configuration to: /tmp/Rtmp4nGYdi/filebc44646f6865/config_file_48196.json
#> Configured steps:
#> genome_alignment: TRUE
#> isoform_identification: TRUE
#> read_realignment: TRUE
#> transcript_quantification: TRUE
#> samtools not found, will use Rsamtools package instead
ppl <- run_FLAMES(ppl)
#> ── Running step: genome_alignment @ Fri Jun 26 08:24:21 2026 ───────────────────
#> Creating junction bed file from GFF3 annotation.
#> Aligning sample sample1 -> /tmp/Rtmp4nGYdi/filebc44646f6865/sample1_align2genome.bam
#> Warning: samtools not found, using Rsamtools instead, this could be slower and might fail for large BAM files.
#> Sorting BAM files by genome coordinates with 1 threads...
#> Indexing bam files
#> Aligning sample sample2 -> /tmp/Rtmp4nGYdi/filebc44646f6865/sample2_align2genome.bam
#> Warning: samtools not found, using Rsamtools instead, this could be slower and might fail for large BAM files.
#> Sorting BAM files by genome coordinates with 1 threads...
#> Indexing bam files
#> Aligning sample sample3 -> /tmp/Rtmp4nGYdi/filebc44646f6865/sample3_align2genome.bam
#> Warning: samtools not found, using Rsamtools instead, this could be slower and might fail for large BAM files.
#> Sorting BAM files by genome coordinates with 1 threads...
#> Indexing bam files
#> ── Running step: isoform_identification @ Fri Jun 26 08:24:22 2026 ─────────────
#> ── Running step: read_realignment @ Fri Jun 26 08:24:22 2026 ───────────────────
#> Realigning sample sample1 -> /tmp/Rtmp4nGYdi/filebc44646f6865/sample1_realign2transcript.bam
#> Warning: samtools not found, using Rsamtools instead, this could be slower and might fail for large BAM files.
#> Skipped sorting BAM files.
#> Realigning sample sample2 -> /tmp/Rtmp4nGYdi/filebc44646f6865/sample2_realign2transcript.bam
#> Warning: samtools not found, using Rsamtools instead, this could be slower and might fail for large BAM files.
#> Skipped sorting BAM files.
#> Realigning sample sample3 -> /tmp/Rtmp4nGYdi/filebc44646f6865/sample3_realign2transcript.bam
#> Warning: samtools not found, using Rsamtools instead, this could be slower and might fail for large BAM files.
#> Skipped sorting BAM files.
#> ── Running step: transcript_quantification @ Fri Jun 26 08:24:24 2026 ──────────
se1 <- experiment(ppl)
se2 <- create_se_from_dir(ppl@outdir, ppl@annotation)