Create Configuration File From Arguments
Arguments
- outdir
the destination directory for the configuration file
- type
use an example config, available values:
- "sc_3end"
- config for 10x 3' end ONT reads
- "SIRV"
- config for the SIRV example reads
- ...
Configuration parameters (using dot for nested parameters)
- seed
- Integer. Seed for minimap2.
- threads
- Number of threads to use.
- do_barcode_demultiplex
- Boolean. Specifies whether to run the barcode demultiplexing step.
- do_genome_alignment
- Boolean. Specifies whether to run the genome alignment step.
TRUEis recommended- do_gene_quantification
- Boolean. Specifies whether to run gene quantification using the genome alignment results.
TRUEis recommended- do_isoform_identification
- Boolean. Specifies whether to run the isoform identification step.
TRUEis recommended- bambu_isoform_identification
- Boolean. Whether to use Bambu for isoform identification.
- multithread_isoform_identification
- Boolean. Whether to use FLAMES' new multithreaded Cpp implementation for isoform identification.
- do_read_realignment
- Boolean. Specifies whether to run the read realignment step.
TRUEis recommended- do_transcript_quantification
- Boolean. Specifies whether to run the transcript quantification step.
TRUEis recommended- barcode_parameters.max_bc_editdistance
- Maximum edit distance for barcode matching
- barcode_parameters.pattern.primer
- Primer sequence pattern
- isoform_parameters.max_dist
- Maximum distance allowed when merging splicing sites
- ...
- Other nested parameters, using dot to indicate nested section
Details
Create a list object containing the arguments supplied in a format
usable for the FLAMES pipeline, and writes the object to a JSON file, which
is located with the prefix 'config_' in the supplied outdir. Default
values from extdata/config_sclr_nanopore_3end.json will be used for
unprovided parameters.
Simple scalar parameters can be set via the ... argument using dot
notation (e.g. barcode_parameters.max_bc_editdistance = 3). For
complex structured parameters such as barcode_parameters.segments
(which is a JSON array of objects), it is strongly recommended to call
create_config(outdir) first to generate the default JSON file, then
open that file in a text editor and modify the segments array
directly. See the FLAMES vignette for a worked example.
Examples
# create the default configuration file
outdir <- tempdir()
config <- create_config(outdir)
#> ℹ Writing configuration to: /tmp/Rtmp4nGYdi/config_file_48196.json
# create config with custom parameters including nested ones
config <- create_config(outdir,
threads = 16,
barcode_parameters.max_bc_editdistance = 3,
barcode_parameters.pattern.primer = "ATCGATCG",
isoform_parameters.min_sup_cnt = 10,
# use the coverage model in oarfish
# via supplying additional CLI arguments
additional_arguments.oarfish = c("--model-coverage")
)
#> ℹ Writing configuration to: /tmp/Rtmp4nGYdi/config_file_48196.json